@@ -1,6 +1,6 @@
 package XTaTIK::Controller::Root;
 
-our $VERSION = '0.005001'; # VERSION
+our $VERSION = '0.005002'; # VERSION
 
 use Mojo::Base 'Mojolicious::Controller';
 use XTaTIK::Common qw/n_to_br  set_product_pic/;
@@ -30,10 +30,22 @@ sub products_category {
             grep exists $_->{number}, $_->{contents}->@*;
     }
 
+    my $title = $self->stash('category') =~ s{^\s*/\s*}{}r;
+    $title = $self->xtext('products_nav_name') unless length $title;
+    $title = join '/', (split m{\s*/\s*}, $title )[-2,-1]
+        if $title =~ tr{/}{} > 1;
+
+    $title =~ s{/}{ / }g;
+
+    my $meta_desc = join ', ', reverse $self->xtext('market'),
+        split m{\s*/\s*}, $title;
+
     $self->stash(
         products    => $products,
         return_path => $return_path,
         return_name => $return_name,
+        page_title  => $title,
+        meta_desc   => $meta_desc,
     );
 }
 
@@ -44,7 +56,17 @@ sub product {
 
     set_product_pic( $self, @$product{qw/image number/} );
 
-    $self->stash( product => $product );
+    my $desc = Mojo::DOM->new( $product->{description} )->all_text;
+    $desc = "$product->{group_desc}; $desc"
+        if length $product->{group_desc};
+
+    $desc = substr($desc, 0, 152) . '...'
+        if length $desc > 155;
+
+    $self->stash(
+        product   => $product,
+        meta_desc => $desc,
+    );
 };
 
 sub contact_post {
